==> qmmp_1.3.1.orig.tar.bz2: qmmp-1.3.1/src/plugins/General/rdetect/translations/rdetect_plugin_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>RDetectFactory</name>
    <message>
        <location filename="../rdetectfactory.cpp" line="30"/>
        <source>Volume Detection Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../rdetectfactory.cpp" line="50"/>
        <source>About Volume Detection Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../rdetectfactory.cpp" line="51"/>
        <source>Qmmp Removable Volume Detection Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../rdetectfactory.cpp" line="52"/>
        <source>This plugin provides removable volume detection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../rdetectfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Γράφτηκε από τον: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>RemovableHelper</name>
    <message>
        <location filename="../removablehelper.cpp" line="134"/>
        <source>Add CD &quot;%1&quot;</source>
        <translation>Προσθήκη CD «%1»</translation>
    </message>
    <message>
        <location filename="../removablehelper.cpp" line="138"/>
        <source>Add Volume &quot;%1&quot;</source>
        <translation>Προσθήκη Έντασης «%1»</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Volume Detection Plugin Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>CD Audio Detection</source>
        <translation>Ανίχνευση CD ήχου</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="38"/>
        <source>Add tracks to playlist automatically</source>
        <translation>Προσθήκη των κομματιών αυτόματα στη λίστα αναπαραγωγής</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>Remove tracks from playlist automatically</source>
        <translation>Αφαίρεση των κομματιών αυτόματα από τη λίστα αναπαραγωγής</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Removable Device Detection</source>
        <translation>Ανίχνευση αφαιρούμενης συσκευής</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="64"/>
        <source>Add files to playlist automatically</source>
        <translation>Προσθήκη αρχείων αυτόματα στη λίστα αναπαραγωγής</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="71"/>
        <source>Remove files from playlist automatically</source>
        <translation>Αφαίρεση των αρχείων από τη λίστα αναπαραγωγής αυτόματα</translation>
    </message>
</context>
</TS>

==> qmmp_1.4.4.orig.tar.bz2: qmmp-1.4.4/src/plugins/General/rdetect/translations/rdetect_plugin_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>RDetectFactory</name>
    <message>
        <location filename="../rdetectfactory.cpp" line="30"/>
        <source>Volume Detection Plugin</source>
        <translation>Πρόσθετο ανίχνευσης έντασης</translation>
    </message>
    <message>
        <location filename="../rdetectfactory.cpp" line="50"/>
        <source>About Volume Detection Plugin</source>
        <translation>Σχετικά με το πρόσθετο ανίχνευσης έντασης</translation>
    </message>
    <message>
        <location filename="../rdetectfactory.cpp" line="51"/>
        <source>Qmmp Removable Volume Detection Plugin</source>
        <translation>Πρόσθετο ανίχνευσης αφαιρούμενης έντασης Qmmp</translation>
    </message>
    <message>
        <location filename="../rdetectfactory.cpp" line="52"/>
        <source>This plugin provides removable volume detection</source>
        <translation>Αυτό το πρόσθετο παρέχει την ανίχνευση αφαιρούμενης έντασης</translation>
    </message>
    <message>
        <location filename="../rdetectfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Γράφτηκε από τον: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>RemovableHelper</name>
    <message>
        <location filename="../removablehelper.cpp" line="134"/>
        <source>Add CD &quot;%1&quot;</source>
        <translation>Προσθήκη CD «%1»</translation>
    </message>
    <message>
        <location filename="../removablehelper.cpp" line="138"/>
        <source>Add Volume &quot;%1&quot;</source>
        <translation>Προσθήκη Έντασης «%1»</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Volume Detection Plugin Settings</source>
        <translation>Ρυθμίσεις του πρόσθετου ανίχνευσης έντασης</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>CD Audio Detection</source>
        <translation>Ανίχνευση CD ήχου</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="38"/>
        <source>Add tracks to playlist automatically</source>
        <translation>Προσθήκη των κομματιών αυτόματα στη λίστα αναπαραγωγής</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>Remove tracks from playlist automatically</source>
        <translation>Αφαίρεση των κομματιών αυτόματα από τη λίστα αναπαραγωγής</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Removable Device Detection</source>
        <translation>Ανίχνευση αφαιρούμενης συσκευής</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="64"/>
        <source>Add files to playlist automatically</source>
        <translation>Προσθήκη αρχείων αυτόματα στη λίστα αναπαραγωγής</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="71"/>
        <source>Remove files from playlist automatically</source>
        <translation>Αφαίρεση των αρχείων από τη λίστα αναπαραγωγής αυτόματα</translation>
    </message>
</context>
</TS>
